@@ -26,11 +26,11 @@ from . import uimodules
 from .config import get_class_from_config, load_yaml_config_file
 import inspect
 import logging
+import os
+from six import iteritems, string_types
 from tornado.escape import json_encode
 from tornado.template import Loader
 import tornado.websocket
-import os
-from six import iteritems, string_types
 
 logger = logging.getLogger(__name__)
 
@@ -114,38 +114,24 @@ class TornadoApplication(tornado.web.Application, data.DataConnectedMixin,
         return self.components[firenado.conf.app['component']]
 
     def __load_components(self):
-        """ Loads all enabled components registered into the components
-        conf.
+        """ Loads all enabled components registered from the components
+        config section.
         """
         for key, value in iteritems(firenado.conf.components):
             if value['enabled']:
                 component_class = get_class_from_config(value)
                 self.components[key] = component_class(key, self)
                 if self.components[key].get_config_file():
-                    filename = self.components[key].get_config_file()
-                    comp_config_file = None
-                    if fs.file_has_extension(filename):
-                        if os.path.isfile(os.path.join(
-                                firenado.conf.APP_CONFIG_PATH, filename)):
-                            comp_config_file = os.path.join(
-                                firenado.conf.APP_CONFIG_PATH, filename)
-                    else:
-                        config_file_extensions = ['yml', 'yaml']
-                        for extension in config_file_extensions:
-                            candidate_filename = os.path.join(
-                                    firenado.conf.APP_CONFIG_PATH,
-                                    "%s.%s" % (filename, extension))
-                            if os.path.isfile(candidate_filename):
-                                comp_config_file = candidate_filename
-                                break
-                    if comp_config_file is not None:
+                    filename = self.components[key].get_complete_config_file()
+                    if filename is not None:
                         self.components[key].conf = load_yaml_config_file(
-                            comp_config_file)
+                            filename)
                         self.components[key].process_config()
+                        self.components[key].has_conf = True
                     else:
                         logger.debug("Failed to find the file for the "
-                                     "component %s at %s. Component filename "
-                                     "returned is %s." % (
+                                     "component %s at %s. Component's "
+                                     "filename returned is %s." % (
                                         key, firenado.conf.APP_CONFIG_PATH,
                                         self.components[key].get_config_file())
                                      )
@@ -165,15 +151,16 @@ class TornadoComponent(object):
         self.name = name
         self.application = application
         self.conf = {}
+        self._has_conf = False
         self.plugins = dict()
 
-    def after_handler(self, handler):
+    def after_request(self, handler):
         """ Add a logic to be executed after all component's handlers
         execution.
         """
         pass
 
-    def before_handler(self, handler):
+    def before_request(self, handler):
         """ Add a logic to be executed before all component's handler
         execution.
         """
@@ -187,6 +174,14 @@ class TornadoComponent(object):
                 return True
         return False
 
+    @property
+    def has_conf(self):
+        return self._has_conf
+
+    @has_conf.setter
+    def has_conf(self, value):
+        self._has_conf = value
+
     def get_handlers(self):
         """ Returns handlers being added by the component to the application.
         :return: A list of handlers the component provides.
@@ -215,6 +210,25 @@ class TornadoComponent(object):
             return filename
         return None
 
+    def get_complete_config_file(self):
+        """ Return the config file with the correct extension, if
+        get_config_file has no extension.
+
+        :return str: The config file with extension
+        """
+        if fs.file_has_extension(self.get_config_file()):
+            if os.path.isfile(self.get_config_file()):
+                return os.path.join(firenado.conf.APP_CONFIG_PATH,
+                                    self.get_config_file())
+        config_file_extensions = ['yml', 'yaml']
+        for extension in config_file_extensions:
+            candidate_filename = "%s.%s" % (self.get_config_file(), extension)
+            if os.path.isfile(os.path.join(
+                    firenado.conf.APP_CONFIG_PATH, candidate_filename)):
+                return os.path.join(firenado.conf.APP_CONFIG_PATH,
+                                    candidate_filename)
+        return None
+
     def get_template_path(self):
         """ Returns the path that holds the component's templates.
         """
@@ -284,11 +298,51 @@ class TornadoHandler(tornado.web.RequestHandler):
 
     @session.read
     def prepare(self):
-        self.component.before_handler(self)
+        self.component.before_request(self)
+        self.before_request()
 
     @session.write
     def on_finish(self):
-        self.component.after_handler(self)
+        self.after_request()
+        self.component.after_request(self)
+
+    def after_request(self):
+        """Called after the end of a request.
+
+        Override this method to perform cleanup, logging, etc.
+        This method is a counterpart to `prepare`.  ``on_finish`` may
+        not produce any output, as it is called after the response
+        has been sent to the client.
+
+        Use this method instead of `on_finish` to avoid the session to break
+        and use session features. This method will be called by `on_finish`
+        with a valid session.
+
+        This method is called before it's component's after_request if defined.
+        """
+        pass
+
+    def before_request(self):
+        """Called at the beginning of a request before  `get`/`post`/etc.
+
+        Override this method to perform common initialization regardless
+        of the request method.
+
+        Use this method instead of `prepare` to avoid the session to break and
+        use session features. This method will be called by `prepare` with
+        a valid session.
+
+        This method is called after it's component's before_request if defined.
+
+        Asynchronous support: Use ``async def`` or decorate this method with
+        `.gen.coroutine` to make it asynchronous.
+        If this method returns an  ``Awaitable`` execution will not proceed
+        until the ``Awaitable`` is done.
+
+        .. versionadded:: 0.1.10
+           Asynchronous support.
+        """
+        pass
 
     def render_string(self, template_name, **kwargs):
         ignore_component = False
